@@ -21,8 +21,7 @@
 
 #include <QWidget>
 
-namespace Ui
-{
+namespace Ui {
 class ImportFinishPage;
 }
 
